import type { AppOptions } from 'firebase-admin';
import { type ExtendedCypressConfig } from './extendWithFirebaseConfig';
import { type protectProduction } from './firebase-utils';
export type PluginConfig = {
    protectProduction?: protectProduction;
};
/**
 * Cypress plugin which attaches tasks used by custom commands
 * and returns modified Cypress config. Modified config includes
 * env setting with values of Firebase specific environment variables
 * such as GCLOUD_PROJECT, FIREBASE_DATABASE_EMULATOR_HOST,
 * FIRESTORE_EMULATOR_HOST and FIREBASE_AUTH_EMULATOR_HOST.
 * @param cypressOnFunc - on function from cypress plugins file
 * @param cypressConfig - Cypress config
 * @param adminInstance - firebase-admin instance
 * @param overrideConfig - Override config for firebase instance
 * @param pluginConfig - Plugin config
 * @returns Extended Cypress config
 */
export default function pluginWithTasks(cypressOnFunc: Cypress.PluginEvents, cypressConfig: Cypress.PluginConfigOptions, adminInstance: any, overrideConfig?: AppOptions, pluginConfig?: PluginConfig): ExtendedCypressConfig;
