"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = pluginWithTasks;
const tslib_1 = require("tslib");
const extendWithFirebaseConfig_1 = tslib_1.__importDefault(require("./extendWithFirebaseConfig"));
const firebase_utils_1 = require("./firebase-utils");
const tasks_1 = tslib_1.__importStar(require("./tasks"));
/**
 * Cypress plugin which attaches tasks used by custom commands
 * and returns modified Cypress config. Modified config includes
 * env setting with values of Firebase specific environment variables
 * such as GCLOUD_PROJECT, FIREBASE_DATABASE_EMULATOR_HOST,
 * FIRESTORE_EMULATOR_HOST and FIREBASE_AUTH_EMULATOR_HOST.
 * @param cypressOnFunc - on function from cypress plugins file
 * @param cypressConfig - Cypress config
 * @param adminInstance - firebase-admin instance
 * @param overrideConfig - Override config for firebase instance
 * @param pluginConfig - Plugin config
 * @returns Extended Cypress config
 */
function pluginWithTasks(cypressOnFunc, cypressConfig, adminInstance, overrideConfig, pluginConfig) {
    // Only initialize admin instance if it hasn't already been initialized
    if (adminInstance.apps && adminInstance.apps.length === 0) {
        (0, firebase_utils_1.initializeFirebase)(adminInstance, overrideConfig, pluginConfig && pluginConfig.protectProduction);
    }
    const tasksWithFirebase = Object.keys(tasks_1.default).reduce((acc, taskName) => {
        acc[taskName] = (taskSettings = {}) => {
            const taskArgs = tasks_1.taskSettingKeys[taskName].map((sk) => taskSettings[sk]);
            // @ts-expect-error - TS cannot know that the right amount of args are passed
            return tasks_1.default[taskName](adminInstance, ...taskArgs);
        };
        return acc;
    }, {});
    // Attach tasks to Cypress using on function
    cypressOnFunc('task', tasksWithFirebase);
    // Return extended config
    return (0, extendWithFirebaseConfig_1.default)(cypressConfig);
}
